 % INITIALIZE CONSTANTS/PROPERTIES
        
        % Water properties:    
        p.c_w= 4193.791;            %  J/kg*K
        p.m_w= 3;                   %  kg
       
        p.rho= 984.549;             %  Average density in kg/m3 . . . 
        % exact density:  rho =( (-0.0036)*(Tw)^2 + 1.8837*(Tw) + 752.67 )
        % where Tw is in Kelvin
        
        p.mu= .00071957;            % Average viscocity in Ns/m2 or Pa*s . . .
        % exact viscocity: mu=((-3*10^-9)*Tw^3 + (3*10^-6)*Tw^2 - 0.001*Tw+0.1117)
        % where Tw is in Kelvin
        
        % Glass properties:
        p.c_g= 840;            %   J/kg*K
        p.m_g= .5;             %   kg

        % Thermal Conductivities:
        p.h_gw= 60;          %   W/m^2*K
        p.h_air= 10;         %   W/m^2*K
        p.k_glass= 1.05;     %   W/(mK)

        % Cylinder Dimensions:
        p.length= .4;              %    meters
        p.r1=.045;                 %    meters
        p.r2=.050;
        p.A_in=(2*pi*p.r1)*p.length;
        p.A_out=(2*pi*p.r2)*p.length;
        p.A_glass=(2*pi*p.length)/log(p.r2/p.r1);

        % Bulb Properties (assume perfect sphere):
        p.R= 0.035;               %   meters
        p.vol= (4/3)*pi*p.R^3;    %   m3
        p.m_b= 0.178786;          %   kg (equilibrium mass @20C)
        p.g= 9.81;                %   m/s2
       
        
% Definitions from User Inputs . . .

    p.Ta= 20 + 273.15;          % Outside temperature  (Kelvin)
    % equilibrium temperature: 293.171 K

    time_interval= [0 finalTime];   % In seconds

    X0= 0;                      % Initial velocity, displacement (meters)
    Y0= [T0 T0 T0 X0 X0];       % Initial temperatures for Tgi, Tgo, and Tw. and initial disp. and velocity
    
% Replace variables with inputs from figure
    p.Ta= Ta;
    
    
% Plot Dimensions/Propertes
scrsz = get(0,'ScreenSize');
figure('Name', 'Galilean Thermometer','Position',[scrsz(3)/10 scrsz(4)/5 scrsz(3)/1.5 scrsz(4)/1.5]);
% Screen size: [left,bottom,width,height]

% Temperature Plot
subplot(221)
options1 = odeset('OutputFcn',@odeplot,'OutputSel',[1 2 3],'RelTol',1e-4);
sol1 = ode45(@therm, time_interval, Y0, options1,p);
title('Temperature vs. Time');
xlabel('Time (seconds)');
ylabel('Temperature (Kelvin)');

% Displacement Plot
subplot(222)
options2 = odeset('OutputFcn',@odeplot,'OutputSel',[4],'RelTol',1e-4);
sol2 = ode45(@therm, time_interval, Y0, options2,p);
title('Displacement vs. Time');
xlabel('Time (seconds)');
ylabel('Displacement (meters)');

% Velocity Plot
subplot(223)
options2 = odeset('OutputFcn',@odeplot,'OutputSel',[5],'RelTol',1e-4);
sol3 = ode45(@therm, time_interval, Y0, options2,p);
title('Velocity vs. Time');
xlabel('Time (seconds)');
ylabel('Velocity (meters/seconds)');
